==> mysql-shell_8.0.38+dfsg.orig.tar.xz: mysql-shell-8.0.38-src/modules/command_interface.h <==
/*
 * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2.0,
 * as published by the Free Software Foundation.
 *
 * This program is designed to work with certain software (including
 * but not limited to OpenSSL) that is licensed under separate terms,
 * as designated in a particular file or component or in included license
 * documentation.  The authors of MySQL hereby grant you an additional
 * permission to link the program and your derivative works with the
 * separately licensed software that they have either included with
 * the program or referenced in the documentation.
 *
 * This program is distributed in the hope that it will be useful,  but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 * the GNU General Public License, version 2.0, for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */

#ifndef MODULES_COMMAND_INTERFACE_H_
#define MODULES_COMMAND_INTERFACE_H_

#include <string>
#include "scripting/lang_base.h"

namespace mysqlsh {

// Command (API) Pure Abstract Class / Interface
// Each API Class must implement this interface
class Command_interface {
 public:
  virtual ~Command_interface() {}

  // Prepare should validate the parameters and other validations.
  // Later, we'd make it acquire locks and save state for the undo (rollback).
  virtual void prepare() = 0;

  // Executes the API command low-level work.
  virtual shcore::Value execute() = 0;

  // Applies the undo.
  virtual void rollback() {}

  // Does the final clean-up, if necessary.
  virtual void finish() {}
};

}  // namespace mysqlsh

#endif  // MODULES_COMMAND_INTERFACE_H_

==> mysql-shell_8.4.7+dfsg.orig.tar.xz: mysql-shell-8.4.7-src/modules/command_interface.h <==
/*
 * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2.0,
 * as published by the Free Software Foundation.
 *
 * This program is designed to work with certain software (including
 * but not limited to OpenSSL) that is licensed under separate terms,
 * as designated in a particular file or component or in included license
 * documentation.  The authors of MySQL hereby grant you an additional
 * permission to link the program and your derivative works with the
 * separately licensed software that they have either included with
 * the program or referenced in the documentation.
 *
 * This program is distributed in the hope that it will be useful,  but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 * the GNU General Public License, version 2.0, for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */

#ifndef MODULES_COMMAND_INTERFACE_H_
#define MODULES_COMMAND_INTERFACE_H_

#include "scripting/types.h"

namespace mysqlsh {

// Command (API) Pure Abstract Class / Interface
// Each API Class must implement this interface
class Command_interface {
 public:
  virtual ~Command_interface() = default;

  // Prepare should validate the parameters and other validations.
  // Later, we'd make it acquire locks and save state for the undo (rollback).
  virtual void prepare() = 0;

  // Executes the API command low-level work.
  virtual shcore::Value execute() = 0;

  // Applies the undo.
  virtual void rollback() {}

  // Does the final clean-up, if necessary.
  virtual void finish() {}
};

}  // namespace mysqlsh

#endif  // MODULES_COMMAND_INTERFACE_H_
